ffigen_js library

Classes

Bool
Char
Float32
Float64
Int16
Int32
Int64
Int8
NativeFunction<T>
NativeType
Sub-classes of NativeType represent a "native" type, meaning a type that can be passed to a WASM-compiled native function), and its equivalent Dart representation.
Null
PointerClass<T extends NativeType>
Struct
Uint16
Uint32
Uint8
Union
Void

Properties

nullptr Pointer<Never>
getter/setter pair
structSizeRegistry Map<Type, int>
Registry of struct sizes (in bytes). Populated by the generated bindings class during initialization. Used by calloc-like allocators that need to know struct sizes at runtime.
final

Functions

addFunction<T>(JSFunction<Function> fn, String signature) Pointer<NativeFunction<T>>
bigInt(String s) JSBigInt
bigIntasUintN(int numBits, JSBigInt bi) JSBigInt
free(Pointer<NativeType> ptr) → void
makeFloat32List(int length) Float32List
makeFloat64List(int length) Float64List
makeInt16List(int length) Int16List
makeInt32List(int length) Int32List
makeInt64List(int length) Int64List
makeIntPtrList(int length) Int32List
makeUint16List(int length) Uint16List
makeUint32List(int length) Uint32List
makeUint8List(int length) Uint8List
malloc<T extends NativeType>(int numBytes) Pointer<T>
sizeOf<T extends NativeType>() int
stackAlloc<T extends NativeType>(int numBytes) Pointer<T>